==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/SimulatePolicyEvaluationsUndefined.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.SimulateResultPoliciesItems;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * A list of undefined but not matched policies and rules
 */
@ApiModel(description = "A list of undefined but not matched policies and rules")
@JsonPropertyOrder({ SimulatePolicyEvaluationsUndefined.JSON_PROPERTY_POLICIES })
@JsonTypeName("SimulatePolicyEvaluations_undefined")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class SimulatePolicyEvaluationsUndefined implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_POLICIES = "policies";
    private List<SimulateResultPoliciesItems> policies = null;

    public SimulatePolicyEvaluationsUndefined() {
    }

    public SimulatePolicyEvaluationsUndefined policies(List<SimulateResultPoliciesItems> policies) {

        this.policies = policies;
        return this;
    }

    public SimulatePolicyEvaluationsUndefined addpoliciesItem(SimulateResultPoliciesItems policiesItem) {
        if (this.policies == null) {
            this.policies = new ArrayList<>();
        }
        this.policies.add(policiesItem);
        return this;
    }

    /**
     * Get policies
     *
     * @return policies
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_POLICIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<SimulateResultPoliciesItems> getPolicies() {
        return policies;
    }

    @JsonProperty(JSON_PROPERTY_POLICIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPolicies(List<SimulateResultPoliciesItems> policies) {
        this.policies = policies;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SimulatePolicyEvaluationsUndefined simulatePolicyEvaluationsUndefined = (SimulatePolicyEvaluationsUndefined) o;
        return Objects.equals(this.policies, simulatePolicyEvaluationsUndefined.policies);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(policies);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SimulatePolicyEvaluationsUndefined {\n");
        sb.append("    policies: ").append(toIndentedString(policies)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/SimulatePolicyEvaluationsUndefined.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.SimulateResultPoliciesItems;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * A list of undefined but not matched policies and rules
 */
@ApiModel(description = "A list of undefined but not matched policies and rules")
@JsonPropertyOrder({ SimulatePolicyEvaluationsUndefined.JSON_PROPERTY_POLICIES })
@JsonTypeName("SimulatePolicyEvaluations_undefined")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class SimulatePolicyEvaluationsUndefined implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_POLICIES = "policies";
    private List<SimulateResultPoliciesItems> policies = null;

    public SimulatePolicyEvaluationsUndefined() {
    }

    public SimulatePolicyEvaluationsUndefined policies(List<SimulateResultPoliciesItems> policies) {

        this.policies = policies;
        return this;
    }

    public SimulatePolicyEvaluationsUndefined addpoliciesItem(SimulateResultPoliciesItems policiesItem) {
        if (this.policies == null) {
            this.policies = new ArrayList<>();
        }
        this.policies.add(policiesItem);
        return this;
    }

    /**
     * Get policies
     *
     * @return policies
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_POLICIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<SimulateResultPoliciesItems> getPolicies() {
        return policies;
    }

    @JsonProperty(JSON_PROPERTY_POLICIES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPolicies(List<SimulateResultPoliciesItems> policies) {
        this.policies = policies;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SimulatePolicyEvaluationsUndefined simulatePolicyEvaluationsUndefined = (SimulatePolicyEvaluationsUndefined) o;
        return Objects.equals(this.policies, simulatePolicyEvaluationsUndefined.policies);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(policies);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SimulatePolicyEvaluationsUndefined {\n");
        sb.append("    policies: ").append(toIndentedString(policies)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
